#-------------------------------------------------------------------------------
#
#  Intended usage:
#
#     ls -FRs | egrep ':$|tot' | awk -f ls2gred.awk > gred file

BEGIN \
{
   # change separator to '/'
   FS = "/"
   node_count = 0;
   edge_count = 0;
}

substr($0,1,5) == "total" {
   if ( node_count > 0 ) {
      node_size[node_count] = substr($0,7,length($0)-6);
   }
   else {
      node_size[1] = substr($0,7,length($0)-6);
   }
}

substr($0,1,5) != "total" {
   # chop prefix (if any); last two columns have relevant info

   child = substr($0,1,length($0)-1);
   parent = substr(child,1,length(child)-length($(NF)));
   clabel = substr($(NF),1,length($(NF))-1);

   if (node_id[parent] == 0) {
      node_count++;
      node_id[parent] = node_count;
      node_label[node_count] = $(NF-1);
      node_ident[node_count] = $(NF-1);
   }

   node_id[child] = ++node_count;
   node_label[node_count] = clabel;
   node_ident[node_count] = substr($0,1,length($0)-1);

   from[++edge_count] = node_id[parent];
   to[edge_count] = node_id[child];
}

END \
{
   printf("set clienta(root) {%s}\n", node_ident[1]);

   for (i=1; i <= node_count; i++) { 
      printf("grCreate v {%s} {%s}\n", node_ident[i], node_label[i]);
      printf("grConfigure v {%s} attr 0 %d\n", node_ident[i], node_size[i] );
   }

   for (i=1; i <= edge_count; i++) {
      f = node_ident[from[i]]
      t = node_ident[to[i]]
      if( blob[f] == "" )
      {
         printf("grCreate b {%s} {%s} {}\n", f, f );
         blob[f] = 1;
      }
      printf("grConfigure v {%s} blob {%s}\n", t, f );
   }
}
